class Antiword < Formula
  desc "Utility to read Word (.doc) files"
  homepage "https://web.archive.org/web/20221207132720/http://www.winfield.demon.nl/"
  url "https://web.archive.org/web/20221207132720/http://www.winfield.demon.nl/linux/antiword-0.37.tar.gz"
  mirror "https://fossies.org/linux/misc/old/antiword-0.37.tar.gz"
  sha256 "8e2c000fcbc6d641b0e6ff95e13c846da3ff31097801e86702124a206888f5ac"
  license "GPL-2.0-or-later"

  livecheck do
    skip "Not actively developed or maintained"
  end

  # This cannot be deprecated while the `textract` formula depends on it.
  # deprecate! date: "2023-09-24", because: :unmaintained

  resource "testdoc.doc" do
    url "https://github.com/rsdoiel/antiword/raw/fe4b579067122a2d9d62647efb1ee7cfe3ca92bb/Docs/testdoc.doc"
    sha256 "4ea5fe94a8ff9d8cd1e21a5e233efb681f2026de48ab1ac2cbaabdb953ca25ac"
  end

  def install
    inreplace "antiword.h", "/usr/share/antiword", pkgshare

    system "make", "CC=#{ENV.cc}",
                   "LD=#{ENV.cc}",
                   "CFLAGS=#{ENV.cflags} -DNDEBUG",
                   "GLOBAL_INSTALL_DIR=#{bin}",
                   "GLOBAL_RESOURCES_DIR=#{pkgshare}"
    bin.install "antiword"
    pkgshare.install Dir["Resources/*"]
    man1.install "Docs/antiword.1"
  end

  def caveats
    <<~EOS
      You can install mapping files in ~/.antiword
    EOS
  end

  test do
    resource("testdoc.doc").stage do
      assert_match <<~EOS, shell_output("#{bin}/antiword testdoc.doc")
        This is just a small test document.


        This is just a small document to see if Antiword has been compiled
        correctly.
        The images will only show in the PostScript mode.

        [pic]

        Figure 1

        This JPEG image is the Antiword icon.

        [pic]

        Figure 2
      EOS
    end
  end
end
